<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="63"/>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Preferências do gerenciador de janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="38"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="43"/>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="48"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="53"/>
        <location filename="../obconf.ui" line="114"/>
        <source>Windows</source>
        <translation>Janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="58"/>
        <source>Move &amp; Resize</source>
        <translation>Mover e redimensionar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="68"/>
        <source>Desktops</source>
        <translation>Áreas de trabalho</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="73"/>
        <source>Margins</source>
        <translation>Margens</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="78"/>
        <source>Dock</source>
        <translation>Doca</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="137"/>
        <source>Window Titles</source>
        <translation>Títulos das janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="143"/>
        <source>Button order:</source>
        <translation>Ordem dos botões:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="439"/>
        <source>Moving and Resizing Windows</source>
        <translation>Movendo e redimensionando janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>Information Dialog</source>
        <translation>Caixas de Diálogo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="701"/>
        <source>Focusing Windows</source>
        <translation>Foco em janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Focar quando o cursor mover sobre a janela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="768"/>
        <source>Titlebar</source>
        <translation>Barra de título</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="905"/>
        <source>Desktop Margins</source>
        <translation>Margens da área de trabalho</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="911"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>As margens da área de trabalho são áreas reservadas nos cantos da tela. Janelas novas não serão dispostas dentro da margem, assim como janelas maximizadas não as cobrirão.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="921"/>
        <source>Left:</source>
        <translation>Esquerda:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="935"/>
        <location filename="../obconf.ui" line="956"/>
        <location filename="../obconf.ui" line="977"/>
        <location filename="../obconf.ui" line="998"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="942"/>
        <source>Top:</source>
        <translation>Topo:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="963"/>
        <source>Right:</source>
        <translation>Direita:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="984"/>
        <source>Bottom:</source>
        <translation>Base:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="329"/>
        <source>All monitors</source>
        <translation>Todos os monitores</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="334"/>
        <source>The active monitor</source>
        <translation>O monitor ativo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="339"/>
        <source>The monitor with the mouse</source>
        <translation>O monitor com o mouse</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="354"/>
        <source>Primary Monitor</source>
        <translation>Monitor primário</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="360"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>O monitor primário é onde o Openbox exibirá diálogos, tais como o diálogo para circular entre as janelas.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="381"/>
        <source>Fixed Monitor</source>
        <translation>Monitor fixo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="386"/>
        <source>Active Monitor</source>
        <translation>Monitor ativo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="391"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Monitor com o cursor</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="549"/>
        <location filename="../obconf.ui" line="578"/>
        <source>Centered</source>
        <translation>Centralizado</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="554"/>
        <source>From left edge</source>
        <translation>Do canto esquerdo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="559"/>
        <source>From right edge</source>
        <translation>Do canto direito</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="583"/>
        <source>From top edge</source>
        <translation>Do topo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="588"/>
        <source>From bottom edge</source>
        <translation>Da base</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="641"/>
        <source>When resizing terminal windows</source>
        <translation>Ao redimensionar janelas de terminal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="646"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="651"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="660"/>
        <source>Centered on the window</source>
        <translation>Centralizado na janela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="665"/>
        <source>Above the window</source>
        <translation>Acima da janela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="670"/>
        <source>Fixed position on screen</source>
        <translation>Posição fixa na tela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="785"/>
        <source>Maximizes the window</source>
        <translation>Maximiza a janela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="790"/>
        <source>Shades the window</source>
        <translation>Sombrear a janela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="153"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Icone da janela
L: Etiqueta da janela (título)
I: Iconificar (minimizar)
M: Maximizar
C: Fechar
S: Sombra (enrolar)
D: onipresente (todas as áreas de trabalho)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="344"/>
        <source>Primary monitor</source>
        <translation>Monitor primário</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1025"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>O dock é um contêiner especial para os &quot;dockapps&quot; ou aplicativos de dock. Não é visível na tela até que um dockapp seja executado. Dockapps podem ser usados para mostrar coisas como um relógio ou para fornecer uma bandeja do sistema.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1053"/>
        <source>&amp;Position:</source>
        <translation>&amp;Posição:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1067"/>
        <source>Top Left</source>
        <translation>Superior Esquerda</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1072"/>
        <source>Top</source>
        <translation>Topo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1077"/>
        <source>Top Right</source>
        <translation>Superior Direito</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1082"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1087"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1092"/>
        <source>Bottom Left</source>
        <translation>Inferior Esquerdo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1097"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1102"/>
        <source>Bottom Right</source>
        <translation>Inferior Direito</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1107"/>
        <source>Floating</source>
        <translation>Flutuante</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1121"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Posicionamento flutuante:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1146"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1162"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Permitir que janelas sejam colocadas dentro da área do dock</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1169"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Orientação: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1183"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1188"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1199"/>
        <source>Stacking</source>
        <translation>Empilhado</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1205"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Manter o dock &amp;acima de outras janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1212"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Permitir que o dock fique acima e abaixo das janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1219"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Manter o dock &amp;abaixo das outras janelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1229"/>
        <source>Hiding</source>
        <translation>Ocultação</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1235"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Atraso antes da ocultação:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1245"/>
        <source>Delay before &amp;showing:</source>
        <translation>Atraso antes de &amp;mostrar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1275"/>
        <source>&amp;Hide off screen</source>
        <translation>&amp;Ocultar a tela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1306"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="96"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Instalar um novo tema...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="103"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Criar um &amp;arquivo de tema (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="120"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Janelas mantém uma borda quando não decoradas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="127"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>A&amp;nimações para minimizar e restaurar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="231"/>
        <source>&amp;Active window title: </source>
        <translation>&amp;Título da janela ativa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="241"/>
        <source>&amp;Inactive window title: </source>
        <translation>&amp;Título da janela inativa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="251"/>
        <source>Menu &amp;header: </source>
        <translation>Cabeçalho do menu: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="261"/>
        <source>&amp;Menu Item: </source>
        <translation>Item do menu: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="271"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Exibição na tela ativa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="281"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Exibição na tela inativa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="295"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Focar em novas janelas quando elas aparecerem</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="302"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Colocar novas janelas abaixo do cursor do mouse</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="309"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Centralizar novas janelas quando elas são abertas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="318"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Colocar novas janelas &amp;em:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="370"/>
        <source>Primary &amp;monitor:</source>
        <translation>Monitor primário:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="399"/>
        <source>&amp;Fixed monitor:</source>
        <translation>Monitor &amp;fixo:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="445"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Atualizar o conteúdo da janela em &amp;redimensionamentos</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="452"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Distância &amp;limite do arraste:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="472"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Resistência contra outras janelas(&amp;w):</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="492"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>R&amp;esistência contra as bordas da tela:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="512"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>Tempo de esper&amp;a antes de mudar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="532"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>Alternar área&amp;s de trabalho ao mover uma janela além da borda da tela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="567"/>
        <source>Fixed &amp;y position:</source>
        <translation>Posição &amp;y:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="596"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Posição do diálogo de informações:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="606"/>
        <source>Fixed &amp;x position:</source>
        <translation>Posição &amp;x:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="616"/>
        <source>Show &amp;information dialog:</source>
        <translation>Exibir diálogo de &amp;informação:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="722"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>Atraso antes &amp;de focar e levantar janelas:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="742"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Muda o foco embaixo do cur&amp;sor ao alternar entre ás áreas de trabalho</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="749"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>M&amp;uda o foco embaixo do cursor quando o mesmo não estiver se movendo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>Sobe janelas quando o pontei&amp;ro do mouse se move sobre elas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="774"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Duplo-clique na barra de &amp;título:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="798"/>
        <source>Double click ti&amp;me:</source>
        <translation>Te&amp;mpo para duplo-clique:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="838"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Exibir uma notificação quando alternar entre área&amp;s de trabalho</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="845"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>Tempo p&amp;ara mostrar a notificação:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="868"/>
        <source>&amp;Number of desktops: </source>
        <translation>Número de áreas de trabalho: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="891"/>
        <source>&amp;Desktop names:</source>
        <translation>Nome das áreas de trabalho:</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Ações Personalizadas</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="65"/>
        <location filename="../desktops.cpp" line="87"/>
        <location filename="../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Área de trabalho sem nome)</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Sobre ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Um gerenciador de preferências para o Openbox

Copyright (C) 2014-2015

Autor:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

O programa é baseado no ObConf, desenvolvido pelos seguintes desenvolvedores:
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../theme.cpp" line="149"/>
        <source>Choose an Openbox theme</source>
        <translation>Escolha um tema para o Openbox</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>&quot;%1&quot; foi instalado em %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; foi criado com sucesso</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Não foi possível criar o arquivo de tema &quot;%1&quot;.
Os seguintes erros foram relatados:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Não foi possível executar o comando &quot;tar&quot;: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Não foi possível criar o diretório &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; não parece ser um diretório válido de tema Openbox</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Não foi possível mover para o diretório &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Não foi possível extrair o arquivo &quot;%1&quot;.
Por favor, certifique-se de que &quot;%2&quot; seja gravável e que o arquivo seja um arquivo de tema válido do Openbox.
Os seguintes erros foram reportados:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Erro ObConf</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Sintaxe: obconf [opções] [ARQUIVO.obt]

Opções:
  --help                                            Mostra essa ajuda e sai
  --version                                      Mostra a versão e sai
  --install ARQUIVO.obt             Instala o arquivo de tema fornecido e o seleciona
  --archive TEMA                          Cria um arquivo de tema a partir do diretório de tema fornecido
  --config-file ARQUIVO             Especifica o caminho para o arquivo de configuração a ser usado
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install requer um argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--install requer um argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file requer um argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="223"/>
        <location filename="../obconf-qt.cpp" line="238"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="224"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Falha para carregar rc.xml Você provavelmente não instalou o Openbox corretamente.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="236"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Erro ao analisar o arquivo de configuração do Openbox. Seu arquivo de configuração não é um XML válido.

Mensagem: %1</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Copyright (C) 2003-2008 Dana Jansens
Copyright (C) 2003 Tim Riley
Copyright (C) 2007 Javeed Shaikh
Direitos autorais 2013 Hong Jen Yee (PCMan)

Este programa vem com ABSOLUTAMENTE NENHUMA GARANTIA.
Isto é software livre, e você está convidado a redistribuí-lo
sob certas condições. Veja o arquivo COPYING para detalhes.

</translation>
    </message>
</context>
</TS>
